BCEWithLogitsLoss
=================

.. currentmodule:: pykeen.losses

.. autoclass:: BCEWithLogitsLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BCEWithLogitsLoss.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~BCEWithLogitsLoss.forward

   .. rubric:: Attributes Documentation

   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: forward
